Index: wp-includes/class-wp-xmlrpc-server.php
===================================================================
--- wp-includes/class-wp-xmlrpc-server.php	(revision 17637)
+++ wp-includes/class-wp-xmlrpc-server.php	(working copy)
@@ -2757,6 +2757,7 @@
 				'categories' => $categories,
 				'mt_excerpt' => $postdata['post_excerpt'],
 				'mt_text_more' => $post['extended'],
+				'wp_more_text' => $post['more_text'],
 				'mt_allow_comments' => $allow_comments,
 				'mt_allow_pings' => $allow_pings,
 				'mt_keywords' => $tagnames,

Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 17637)
+++ wp-includes/post.php	(working copy)
@@ -319,29 +319,32 @@
  * 'more'. There can be text or space(s) after the word 'more', but won't be
  * referenced.
  *
  * The returned array has 'main' and 'extended' keys. Main has the text before
  * the <code><!--more--></code>. The 'extended' key has the content after the
- * <code><!--more--></code> comment.
+ * <code><!--more--></code> comment. The 'more_text' key has the custom "Read more text".
  *
  * @since 1.0.0
  *
  * @param string $post Post content.
  * @return array Post before ('main') and after ('extended').
  */
 function get_extended($post) {
 	//Match the new style more links
 	if ( preg_match('/<!--more(.*?)?-->/', $post, $matches) ) {
 		list($main, $extended) = explode($matches[0], $post, 2);
+		$more_text = $matches[1];
 	} else {
 		$main = $post;
 		$extended = '';
+		$more_text = '';
 	}
 
 	// Strip leading and trailing whitespace
 	$main = preg_replace('/^[\s]*(.*)[\s]*$/', '\\1', $main);
 	$extended = preg_replace('/^[\s]*(.*)[\s]*$/', '\\1', $extended);
+	$more_text = preg_replace('/^[\s]*(.*)[\s]*$/', '\\1', $more_text);
 
-	return array('main' => $main, 'extended' => $extended);
+	return array('main' => $main, 'extended' => $extended, 'more_text' => $more_text);
 }
 
 /**
@@ -319,29 +319,32 @@
  * referenced.
  *
- * The returned array has 'main' and 'extended' keys. Main has the text before
+ * The returned array has 'main', 'extended', and 'more_text' keys. Main has the text before
  * the <code><!--more--></code>. The 'extended' key has the content after the
@@ -319,29 +319,32 @@
  *
  * @param string $post Post content.
- * @return array Post before ('main') and after ('extended').
+ * @return array Post before ('main') and after ('extended'), and custom readmore text ('more_text')
  */
 function get_extended($post) {